@@ -1,15 +1,17 @@
-#' Create a complete ggplot for Spat* objects
+#' Create a complete ggplot for `Spat*` objects
 #'
-#' `autoplot()` uses ggplot2 to draw plots as the ones produced by
+#' `autoplot()` uses \CRANpkg{ggplot2} to draw plots as the ones produced by
 #' [terra::plot()]/[terra::plotRGB()] in a single command.
 #'
-#' Implementation of [ggplot2::autoplot()].
+#' Implementation of [ggplot2::autoplot()] method.
 #'
-#' @return A ggplot2 layer
+#' @return A \CRANpkg{ggplot2} layer
 #' @family ggplot2.utils
 #' @family ggplot2.methods
-#' @param object A SpatRaster created with [terra::rast()] or a SpatVector
+#'
+#' @param object A `SpatRaster` created with [terra::rast()] or a `SpatVector`
 #'   created with [terra::vect()].
+#'
 #' @rdname autoplot.Spat
 #' @name autoplot.Spat
 #'
@@ -20,6 +22,7 @@
 #'   try to guess. See also [scale_fill_coltab()].
 #' @param facets Logical. Should facets be displayed? If `NULL` (the default)
 #'   [autoplot.SpatRaster()] would try to guess.
+#'
 #' @param nrow,ncol Number of rows and columns on the facet.
 #' @param ... other arguments passed to [geom_spatraster()],
 #'  [geom_spatraster_rgb()] or [geom_spatvector()].
@@ -29,14 +32,14 @@
 #'
 #' Implementation of the **generic** [ggplot2::autoplot()] function.
 #'
-#' ## SpatRaster
+#' ## `SpatRaster`
 #'
 #' Uses [geom_spatraster()] or [geom_spatraster_rgb()].
 #'
-#' ## SpatVector
+#' ## `SpatVector`
 #'
 #' Uses [geom_spatvector()]. Labels can be placed with [geom_spatvector_text()]
-#' or [geom_spatvector_label()]
+#' or [geom_spatvector_label()].
 #'
 #' @export
 #' @importFrom ggplot2 autoplot
@@ -109,13 +112,13 @@ autoplot.SpatRaster <- function(object,
 
 
   if (!use_coltab) {
-    todf <- terra::as.data.frame(object, na.rm = TRUE, xy = FALSE)
+    todf <- terra::as.data.frame(object[1, ], na.rm = TRUE, xy = FALSE)
     first_lay <- unlist(lapply(todf, class))[1]
 
     if (first_lay %in% c("character", "factor")) {
-      gg <- gg + scale_fill_terrain_d()
+      gg <- gg + scale_fill_grass_d()
     } else {
-      gg <- gg + scale_fill_terrain_c()
+      gg <- gg + scale_fill_grass_c()
     }
   }
 
