@@ -145,7 +145,8 @@ geom_spatraster_contour <- function(mapping = NULL, data,
                                     breaks = NULL,
                                     na.rm = TRUE,
                                     show.legend = NA,
-                                    inherit.aes = TRUE) {
+                                    inherit.aes = TRUE,
+                                    mask_projection = FALSE) {
   # Is a suggestion so far
   # nocov start
   if (!requireNamespace("isoband", quietly = TRUE)) {
@@ -237,6 +238,7 @@ geom_spatraster_contour <- function(mapping = NULL, data,
       breaks = breaks,
       # Extra params
       maxcell = maxcell,
+      mask_projection = mask_projection,
       ...
     )
   )
@@ -290,7 +292,7 @@ StatTerraSpatRasterContour <- ggplot2::ggproto(
   default_aes = ggplot2::aes(lyr = lyr, order = after_stat(level)),
   extra_params = c(
     "maxcell", "bins", "binwidth", "breaks", "na.rm",
-    "coord_crs"
+    "coord_crs", "mask_projection"
   ),
   setup_params = function(data, params) {
     range_lys <- lapply(data$spatraster, terra::minmax)
@@ -327,12 +329,12 @@ StatTerraSpatRasterContour <- ggplot2::ggproto(
   },
   compute_group = function(data, scales, z.range, bins = NULL, binwidth = NULL,
                            breaks = NULL, na.rm = FALSE, coord,
-                           coord_crs = NA) {
+                           coord_crs = NA, mask_projection = FALSE) {
     # Extract raster from group
     rast <- data$spatraster[[1]]
 
     # Reproject if needed
-    rast <- reproject_raster_on_stat(rast, coord_crs)
+    rast <- reproject_raster_on_stat(rast, coord_crs, mask = mask_projection)
     # To data and prepare
     prepare_iso <- pivot_longer_spat(rast)
     # Keep initial data
